/*
** Module   : XDocument
** Abstract : DOM XML Document resource type interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 EVL 20130130 Created initial version.
*/

package com.goldencode.p2j.xml;

import org.w3c.dom.*;
import com.goldencode.p2j.util.*;

/**
 * Interface describinf X-Document specific features of the DOM XML objects.
 */
public interface XDocument
extends XEntity
{
   // Methods
   // Returning value placed into hChild
   /**
    * Creating the new node within the current Document object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNode(handle hChild, String name, String type);
   
   /**
    * Creating the new node within the current Document object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNode(handle hChild, character name, String type);
   
   /**
    * Creating the new node within the current Document object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNode(handle hChild, String name, character type);
   
   /**
    * Creating the new node within the current Document object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNode(handle hChild, character name, character type);

   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, String uri,
                                      String name, String type);
   
   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, character uri,
                                      String name, String type);
   
   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, String uri,
                                      character name, String type);
   
   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, String uri,
                                      String name, character type);
   
   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, String uri,
                                      character name, character type);
   
   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, character uri,
                                      String name, character type);
   
   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, character uri,
                                      character name, String type);
   
   /**
    * Creating the new node within the current Document object using different
    * approach based on the name space URI.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be created and
    *           returned on method call to use further.
    * @param    uri
    *           The URI namespace of the node to be created.
    * @param    name
    *           The name of the node to be created.
    * @param    type
    *           The type of the node to be created.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical createNodeNamespace(handle hChild, character uri,
                                      character name, character type);
   
   // Returning value placed into hRoot
   /**
    * Getting the root node for the current document. The handle is placed
    * into passed object reference.
    * 
    * @param    hRoot
    *           The valid handle class instance variable to receive the
    *           result.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical getDocumentElement(handle hRoot);
   
   /**
    * Loading X-Document form file or memptr sources.
    * 
    * @param    mode
    *           Variable indicating the type of source to read. "file" means
    *           reading from file, "memptr" means reading from memory buffer.
    * @param    source
    *           If mode == "file" this is the file name, if "memptr" this is
    *           the memptr object.
    * @param    validate
    *           Flag indicating whether to validate while reading or not.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical load(String mode, Object source, logical validate);
   
   /**
    * Loading X-Document form file or memptr sources.
    * 
    * @param    mode
    *           Variable indicating the type of source to read. "file" means
    *           reading from file, "memptr" means reading from memory buffer.
    * @param    source
    *           If mode == "file" this is the file name, if "memptr" this is
    *           the memptr object.
    * @param    validate
    *           Flag indicating whether to validate while reading or not.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical load(String mode, Object source, boolean validate);
   
   /**
    * Loading X-Document form file or memptr sources.
    * 
    * @param    mode
    *           Variable indicating the type of source to read. "file" means
    *           reading from file, "memptr" means reading from memory buffer.
    * @param    source
    *           If mode == "file" this is the file name, if "memptr" this is
    *           the memptr object.
    * @param    validate
    *           Flag indicating whether to validate while reading or not.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical load(character mode, Object source, boolean validate);
   
   /**
    * Loading X-Document form file or memptr sources.
    * 
    * @param    mode
    *           Variable indicating the type of source to read. "file" means
    *           reading from file, "memptr" means reading from memory buffer.
    * @param    source
    *           If mode == "file" this is the file name, if "memptr" this is
    *           the memptr object.
    * @param    validate
    *           Flag indicating whether to validate while reading or not.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical load(character mode, Object source, logical validate);
   
   /**
    * Saving X-Document to file or stream or memptr object.
    * 
    * @param    mode
    *           Variable indicating the type of target to write. "file" means
    *           writing to file, "stream" means writing to the stream and
    *           "memptr" means writing to memory buffer.
    * @param    target
    *           If mode == "file" this is the file name, if "stream" means
    *           output stream, if "memptr" this is the memptr object.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical save(String mode, Object target);

   /**
    * Saving X-Document to file or stream or memptr object.
    * 
    * @param    mode
    *           Variable indicating the type of target to write. "file" means
    *           writing to file, "stream" means writing to the stream and
    *           "memptr" means writing to memory buffer.
    * @param    target
    *           If mode == "file" this is the file name, if "stream" means
    *           output stream, if "memptr" this is the memptr object.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical save(character mode, Object target);
}
