/*
** Module   : XmlFactory
** Abstract : DOM XML instances creation.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 EVL 20130130 Created initial version.
*/

package com.goldencode.p2j.xml;

import org.w3c.dom.*;
import com.goldencode.p2j.util.*;

/**
 * The set of methods to work with DOM XML support implementation in P2J.
 */
public class XmlFactory
{
   /**
    * Constructs a new instance of the Progress X-Document object and
    * retrieves the handle variable associated with it.
    *
    * @return The handle variable associated with the newly created DOM XML
    *         document.
    */
   public static handle createXDocument()
   {
      XDocumentImpl res = new XDocumentImpl();
      return res.getHandle();
   }

   /**
    * Constructs a new instance of the Progress X-Node-Reference object and
    * retrieves the handle variable associated with it.
    *
    * @return The handle variable associated with the newly created DOM XML
    *         node reference.
    */
   public static handle createXNodeReference()
   {
      XNodeRefImpl res = new XNodeRefImpl(); 
      return res.getHandle();
   }

   /**
    * Constructs a new instance of the Progress X-Node-Reference object and
    * retrieves the handle variable associated with it. The approach is
    * slightly different. Each node will have additional paranmeter - Name
    * Space and node will be addressed by namespace and name pair instead
    * of the simple name.
    *
    * @param  nsUri
    *         Name space associated with the current set of names.
    *
    * @return The handle variable associated with the newly created DOM XML
    *         node reference.
    */
   public static handle createXNodeReference(character nsUri)
   {
      XNodeRefImpl res = new XNodeRefImpl(nsUri); 
      return res.getHandle();
   }
}
